@@ -2,6 +2,8 @@ friendly_class_undefined_message <- quanteda:::friendly_class_undefined_message
 message_error <- quanteda:::message_error
 removals_regex <- quanteda:::removals_regex
 pad_dfm <- quanteda:::pad_dfm
+get_docvars <- quanteda:::get_docvars
+get_docvars.dfm <- quanteda:::get_docvars.dfm
 
 #' Check arguments passed to other functions via ...
 #' @param ... dots to check
